@@ -3,9 +3,6 @@ context("PipeOpClassBalancing")
 test_that("PipeOpClassBalancing - basic properties", {
   op = PipeOpClassBalancing$new()
   task = mlr_tasks$get("iris")
-  expect_pipeop(op)
-  train_pipeop(op, inputs = list(task))
-  predict_pipeop(op, inputs = list(task))
 
   expect_datapreproc_pipeop_class(PipeOpClassBalancing, task = task,
     predict_like_train = FALSE, deterministic_train = FALSE)
