@@ -70,3 +70,19 @@ test_that("PipeOpRemoveConstants removes expected cols", {
   test_dropping(minus.iris , minus.iris, list())
 
 })
+
+test_that("PipeOpRemoveConstants handles integer overflow constants", {
+  n = 5L
+  big = .Machine$integer.max
+  dt = data.table(
+    const = c(rep.int(big, n - 1L), big - 1L),
+    vary = c(big, big - 10L, big - 20L, big - 30L, big - 40L),
+    target = factor(c("a", "a", "b", "b", "b"))
+  )
+
+  task = TaskClassif$new("overflow", dt, target = "target")
+  po = PipeOpRemoveConstants$new(param_vals = list(abs_tol = 0))
+
+  result = po$train(list(task))[[1]]
+  expect_false("const" %in% result$feature_names)
+})
